; ******************************************************************************************************************
; **  PROGRAMME MAKED BY FADISHOP  	Card: FADICLOCK  http://www.fadishop.eu	FADITECO, S.L.U. 	Lleonard Garcia	**
; **  This program reads date-time. Is modified to apply every 2 seconds a temperature reading				**
; ** 													      					**
; **  SLAVE ADDRESS IS STILL DS3232 I2C $ D0.												**
; **	SQW INTERRUPT ROUTING JP6 (BLUE JUMPER) (I0 = 1 I1 = 0, I2 = 0, portC.7 = 1; Rpullup = 1)				**
; ******************************************************************************************************************
; SETTINGS
#picaxe 28x2		
let dirsB=%00000000	; 1=output 0=input
let dirsC=%00000000	; 1=output 0=input
; C.3 I2C_SCL
; C.4 I2C_SDA
;adcsetup = %00000000 	; SETTING ANALOG
;setfreq em16		; Oscillator / external oscillator to 16Mhz.
device_DS3232SN:
symbol adress_slave_A =$D0	; Address 0xD0 DS3232 I2C only.
symbol @now=$00			; Internal adress register of seconds, minutes and hours.
symbol @today=$03			; Internal adress register of day, month and year-century.
symbol @alm1=$07			; Internal adress register alarm_1 (sec, min, hour and day / day).
symbol @alm2=$0B			; Internal adress register alarma2 (min, hour and day / day).
symbol @control=$0E		; (7)/EOSC (6)BBSQW (5)CONV (4-3)RS2-1 (2)INTCN (1)A2IE (0)A1IE
symbol @status=$0F		; (7)OSF (6)BB32KHZ (5-4)CRATE (3)EN32KHZ (2)BSY (1)A2F (0)A1F
symbol @offset=$10		; temperature offset. (adds / subtracts capacitance)
symbol @temp=$11			; Internal word temperature address($11-MSB_temperature and $12-LSB_temperature) .
symbol @test=$13			; Reserved for test.
symbol @sram=$14			; Internal address of the start of the block of 236 bytes SRAM.
symbol control=b16		; Register/shadow control DS3232.
symbol status=b18			; Register/shadow control/status DS3232.
; Program Definitions and Initialization
symbol seconds=b0
symbol minutes=b1
symbol hour=b2
symbol day=b3
symbol date=b4
symbol mounth=b5
symbol year=b6
symbol T_msb=b7
symbol T_lsb=b8

;INITIALIZATIONS:
let control=%00011100					; Matches defecto.POR initialization (power on reset).
let control=control and %11111011			; bit (2) INTCN = 0. The output INT / SQW is output wave form.
let control=control and %11100111			; bits (3-4) RS1 = 0, RS2 = 0.Frequencia SQUARE-WAVE: 1HZ.
;let control=control or %01000000			; bit (6) = 1 -> INT / SQW ranges when Vbat feed DS3232.
let status=%11001000					; Matches defecto.POR initialization (power on reset).
let status=status and %11110111			; bit (3) = 0 -> output is inhibited (32 kHz) when Vcc feed DS3232.
let status=status and %10111111			; Bit (6) = 0 -> output is inhibited (32 kHz) when Vbat feed DS3232.
i2cslave adress_slave_A, i2cslow, i2cbyte		; DS3232 I2C Address (0xD0-0xD1).
writei2c @control,(control,status)			; Settings are sent and ratings.
;call set_time_date					; change the date-time DS3232 RTC.
;call set_alarm1						; alarm_1 sets the DS3232 RTC.
configuracio_interrupcions:
setint %10000000,%10000000 				; are enabled by high pinC.7 interruptions.

main:
i2cslave adress_slave_A, i2cslow, i2cbyte		; DS3232 I2C Address (0xD0-0xD1)
readi2c @now,(seconds,minutes,hour,day)		; Read now (seconds minutes, hour and day)
readi2c @today,(date,mounth,year)			; Read today (date, mounth and year)
readi2c @temp,(T_msb,T_lsb)				; Read 2 bytes temperature
readi2c @alm1,(b10,b11,b12,b13)			; Read alarma_1.
readi2c @control,(b17,b19)				; Read control registers.
debug								; Output data to display PC
PAUSE 5000							; Pause 5 seconds
goto main							; Reboot

; INTERRUPT SEQUENCE
interrupt:							; It has previously been low? MSB: b21, LSB: b22.
if b20=0 then inc w11					; (YES) Increase word register.
		  let b20=255				; (YES) Note that is high.
		  setint %00000000,%10000000 		; (YES) Are enabled by low pinC.7 interruptions?
	   else let b20=0					; (NO) Records that is low.
		  setint %10000000,%10000000 		; (NO) are enabled by high pinC.7 interruptions.
endif
return							; 

; SUBRUTINE
set_time_date:
symbol xseg=$25						; @_intern DS3232: $00
symbol xminu=$00						; @_intern DS3232: $01
symbol xhora=$13						; @_intern DS3232: $02
symbol xsemdia=$00					; @_intern DS3232: $03
symbol xdia=$03						; @_intern DS3232: $04
symbol xmes=$03						; @_intern DS3232: $05
symbol xanno=$12						; @_intern DS3232: $06
i2cslave adress_slave_A, i2cslow, i2cbyte		; Adress I2C of DS3232 (0XD0-0XD1)
writei2c @now,(xseg,xminu,xhora,xsemdia,xdia,xmes,xanno); It send current date-time to the RTC DS3232.
return

set_alarm1:
symbol a1_seg=$00
symbol a1_min=$01
symbol a1_hor=$13						; Time format->bit(6)=0:24h, bit(6)=1:AM/PM 12h.
symbol a1_dia_sem=$03					; Day format-> bit(6)=0:dia del mes, bit(6)=1:dia de la semana.
i2cslave adress_slave_A, i2cslow, i2cbyte		; Adress I2C of DS3232 (0XD0-0XD1)
writei2c @alm1,(a1_seg,a1_min,a1_hor,a1_dia_sem); It sends the settings of the alarma_1.
let control=control or %00000001			; Interruption is enabled alarma_1 A1E.
let control=control or %00000100			; Alarm interrupt is enabled INTCN in DS3232.
let status=status and %11111110			; Flag is cleared alarma_1 in DS3232.
writei2c @control,(control,status)			; It sends and delete flag clearance A1F.
return

set_alarm2:
symbol a2_min=$01
symbol a2_hor=$13						; Time Format-> bit (6) h = 0:24, bit (6) = 1: AM / PM 12h.
symbol a2_dia_sem=$03					; Day format-> bits (6) = 0: day of the month, bit (6) = 1: day of the week.
i2cslave adress_slave_A, i2cslow, i2cbyte		; Direccin I2C del DS3232 (0XD0-0XD1)
writei2c @alm2,(a2_min,a2_hor,a2_dia_sem)		; It sends the settings of the alarma_2.
let control=control or %00000010			; Interruption is enabled alarma_1 A2E.
let control=control or %00000100			; Alarm interrupt is enabled INTCN in DS3232.
let status=status and %11111101			; Flag is cleared alarma_2 in DS3232.
writei2c @control,(control,status)			; It sends and delete flag clearance A2F.
return